@@ -175,11 +175,17 @@
 		if (x$typeof == 0){
 			cat(paste("      penalized marginal log-likelihood =", round(x$logLikPenal,2)))
 			cat("\n")
+			cat("      Convergence criteria: \n")
+			cat("      parameters =",signif(x$EPS[1],3),"likelihood =",signif(x$EPS[2],3),"gradient =",signif(x$EPS[3],3),"\n")
+			cat("\n")
 			cat("      LCV = the approximate likelihood cross-validation criterion\n")
 			cat("            in the semi parametrical case     =",x$LCV,"\n")
 		}else{
 			cat(paste("      marginal log-likelihood =", round(x$logLik,2)))
 			cat("\n")
+			cat("      Convergence criteria: \n")
+			cat("      parameters =",signif(x$EPS[1],3),"likelihood =",signif(x$EPS[2],3),"gradient =",signif(x$EPS[3],3),"\n")
+			cat("\n")
 			cat("      AIC = Aikaike information Criterion     =",x$AIC,"\n")
 			cat("\n")
 			cat("The expression of the Aikaike Criterion is:","\n")
@@ -211,7 +217,9 @@
 			cat("\n")
 		}
 		
-		cat("      n events=", x$n.event, " n groups=", x$groups)
+		if (!is.null(frail)) cat("      n events=", x$n.events, " n groups=", x$groups)
+		else cat("      n events=", x$n.events)
+		
 		cat( "\n")
 		cat("      number of iterations: ", x$n.iter,"\n")
 		if ((x$typeof == 1) & (x$indic.nb.int1 == 1)){
@@ -272,6 +280,11 @@
 			if (x$nvartimedep != 0) cat("  and some time-dependant covariates","\n")
 			if (x$n.strat>1) cat("  (Stratification structure used)", "\n")
 		}
+		cat("\n")
+		
+		cat("      Convergence criteria: \n")
+		cat("      parameters =",signif(x$EPS[1],3),"likelihood =",signif(x$EPS[2],3),"gradient =",signif(x$EPS[3],3),"\n")
+		
 		cat("\n")
 		cat("      n=", x$n)
 		
@@ -281,7 +294,9 @@
 			cat("\n")
 		}
 
-		cat("      n events=", x$n.event, " n groups=", x$groups)
+		if (!is.null(frail)) cat("      n events=", x$n.events, " n groups=", x$groups)
+		else cat("      n events=", x$n.events)
+		
 		cat( "\n")
 		cat("      number of iterations: ", x$n.iter)
 	}
